package com.edgec.browserbackend.domain.account;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import org.hibernate.validator.constraints.Length;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Document(collection = "accounts")
@JsonIgnoreProperties(ignoreUnknown = true)
public class Account {

    @Id
    private String name;

    private String parent;

    private Date lastSeen;

    private Date signupDate = new Date();

    private String email;

    private String companyName;

    private String jobTitle;

    private String phoneNumber;

    private String country;

    private String province;

    private String agencyID;

    private String lockReason;

    private int iprate;

    private boolean isPrePaid = true;

    private boolean isVpsUser = false;

    private String token;

    /**
        是否具有参与免费试用两小时云主机资格
     */
    private Boolean isQualified=true;

    public Boolean isQualified() {
        return isQualified;
    }

    public void setQualified(Boolean qualified) {
        isQualified = qualified;
    }

    public boolean isVpsUser() {
        return isVpsUser;
    }

    public void setVpsUser(boolean vpsUser) {
        isVpsUser = vpsUser;
    }

    public int getIprate() {
        return iprate;
    }

    public void setIprate(int iprate) {
        this.iprate = iprate;
    }

    public String getAgencyID(){
        return agencyID;
    }

    public void setAgencyID(String agencyID){
        this.agencyID = agencyID;
    }

    private boolean allowedToCreateSubUser = false;

    private boolean allowedToCreateCloudAccount = false;

    private List<UserService> userServices = new ArrayList<>();

    public List<UserService> getUserServices() {
        return userServices;
    }

    public void addUserService(UserService service) {
        this.userServices.add(service);
    }

    public void setUserServices(List<UserService> userServices) {
        this.userServices = userServices;
    }

    public Date getSignupDate() {
        return signupDate;
    }

    public void setSignupDate(Date signupDate) {
        this.signupDate = signupDate;
    }

    public boolean isPrePaid() {
        return isPrePaid;
    }

    public void setPrePaid(boolean prePaid) {
        isPrePaid = prePaid;
    }

    public boolean isAllowedToCreateCloudAccount() {
        return allowedToCreateCloudAccount;
    }

    public void setAllowedToCreateCloudAccount(boolean allowedToCreateCloudAccount) {
        this.allowedToCreateCloudAccount = allowedToCreateCloudAccount;
    }

    public Account() {
    }

    public Account(AccountDto account) {
        this.setName(account.getName());
        this.setAllowedToCreateSubUser(account.isAllowedToCreateSubUser());
        this.setAllowedToCreateCloudAccount(account.isAllowedToCreateCloudAccount());
        this.setCompanyName(account.getCompanyName());
        this.setCountry(account.getCountry());
        this.setEmail(account.getEmail());
        this.setJobTitle(account.getJobTitle());
        this.setPhoneNumber(account.getPhoneNumber());
        this.setProvince(account.getProvince());
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getCompanyName() {
        return companyName;
    }

    public void setCompanyName(String companyName) {
        this.companyName = companyName;
    }

    public String getJobTitle() {
        return jobTitle;
    }

    public void setJobTitle(String jobTitle) {
        this.jobTitle = jobTitle;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public String getCountry() {
        return country;
    }

    public void setCountry(String country) {
        this.country = country;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    @Length(min = 0, max = 20000)
    private String note;

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Date getLastSeen() {
        return lastSeen;
    }

    public void setLastSeen(Date lastSeen) {
        this.lastSeen = lastSeen;
    }

    public String getNote() {
        return note;
    }

    public void setNote(String note) {
        this.note = note;
    }

    public String getParent() {
        return parent;
    }

    public void setParent(String parent) {
        this.parent = parent;
    }

    public boolean isAllowedToCreateSubUser() {
        return allowedToCreateSubUser;
    }

    public void setAllowedToCreateSubUser(boolean allowedToCreateSubUser) {
        this.allowedToCreateSubUser = allowedToCreateSubUser;
    }

    public String getLockReason() {
        return lockReason;
    }

    public void setLockReason(String lockReason) {
        this.lockReason = lockReason;
    }

    public String getToken() {
        return token;
    }

    public void setToken(String token) {
        this.token = token;
    }


}
