package com.edgec.browserbackend.service.account;

import com.edgec.browserbackend.account.domain.*;
import com.edgec.browserbackend.domain.account.*;
import com.edgec.browserbackend.dto.BillQueryCriteriaDto;
import com.edgec.browserbackend.dto.CloudUserOrderDto;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.Date;
import java.util.List;

public interface AccountService {

    /**
     * Finds account by given name
     *
     * @param accountName
     * @return found account
     */
    Account findByName(String accountName);

    /**
     * Checks if account with the same name already exists
     * Invokes Auth Service user creation
     * Creates new account with default parameters
     *
     * @param user
     * @return created account
     */
    Account create(User user);


    Account createWithSms(User user);

    /**
     * Validates and applies incoming account updates
     * Invokes Statistics Service update
     *
     * @param name
     * @param update
     */
    Account saveChanges(String name, Account update);

    void resetPassword(UserDto user);

    Account createSub(String name, AccountDto user);

    void deleteSub(String parent, String child);

    void deleteByName(String name);

    UserDto determUsernameOrEmail(String text);

    Account saveSub(String name, AccountDto user);

    List<UserDto> getAllDesendentUsers(String name, int level);

    List<UserBillList> getUserBills0(String name);

    List<UserBillList> getUserBills(String name, Services services);

    void resetPasswordWithOtp(UserDto user);

    IpChargeResultDto preCharge(String name, IpChargeRequestDto requestDto);

    IpChargeResultDto preChargeByMoney(String name, double money);

    IpChargeResultDto preChargeIp(String name, int amount, double money);

    IpChargeResultDto charge(String name, IpChargeRequestDto requestDto);

    IpChargeResultDto chargeByMoney(String name, double money, IpChargeRequestDto requestDto);

    Page<UserPayment> getUserPayment(Pageable pageable, String username);

    void sendSmsOtp(String phone, String by);

    AccountDto getAccountByCellphone(String cellphone);

    String queryVpsRate(String region, String instanceSpecKey, String chargeType);

    String queryUserChargeRate(String username, IpChargeRequestDto requestDto);

    Page<UserPrePaidBilling> listPrepaid(Pageable pageable, String username, String[] chargeType, int year, int month, int day, String zoneId);

    Page<UserPrePaidBilling> listBills(Pageable pageable, String username, BillQueryCriteriaDto billQueryCriteriaDto, String dateFrom, String dateTo, String zoneId);

    Page<Account> listAccountBySingupDate(Pageable pageable, Date beginDate, Date endDate);

    Account findByName(String accountName, boolean isVpsUser);

    List<UserBillList> findOverviewByYearAndMonth(String username, int year, int mont, String zoneId, Services service);

    IpChargeResultDto preOrder(String userName, IpChargeRequestDto requestDto);

    String deletePreOrder(String userName);

    boolean isIdcardAuth(String idCard, String type);

    List<Invoice> findByUsername(String username);

    boolean writeInvoice(Invoice invoice);

    int invoiceSize(String username);

    void updateUserToken(String username, String token);

    String createCloudUserOrder(String username, CloudUserOrderDto cloudUserOrderDto);

    CloudUserOrder queryCloudUserOrder(String username, String tradeNo);

    CloudUserOrderDto queryCloudUserOrderDto(String username, String tradeNo);

    List<CloudUserOrder> queryAllCloudUserOrder(String username, String service, String status);

    CloudUserOrder updateCloudUserOrder(String username, String tradeNo, String status);

    void updateCloudUserOrder(String tradeNo, String status);

    void payCloudUserOrderByAli(HttpServletRequest request, HttpServletResponse response, String tradeNo) throws IOException;

    UserPaymentDto payCloudUserOrderByWx(String username, String tradeNo);

    /**
     * 查询是否具有免费试用资格
     * @param username 用户名
     * @return 是否有资格
     */
    boolean queryQualified(String username);

    boolean bingdOrderWithCloudUser(String tradeNo, String username);

    void removeQualified(String username);

}
